package #
Locale::Codes::LangVar_Retired;

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'deprecate_codes' is run.
#    Generated on: Fri Feb 23 12:58:17 EST 2018

use strict;
require 5.006;
use warnings;
use utf8;

our($VERSION);
$VERSION='3.56';

$Locale::Codes::Retired{'langvar'}{'alpha'}{'code'} = {
};

$Locale::Codes::Retired{'langvar'}{'alpha'}{'name'} = {
   q("academic" ("governmental") variant of belarusian as) => [ q(1959acad), q("Academic" ("governmental") variant of Belarusian as) ],
   q(portugese language orthographic agreement of 1990 (acordo ortografico da lingua portuguesa de 1990)) => [ q(ao1990), q(Portugese Language Orthographic Agreement of 1990 (Acordo Ortografico da Lingua Portuguesa de 1990)) ],
   q(slovene in bohoric alphabet) => [ q(bohoric), q(Slovene in Bohoric alphabet) ],
};


1;
